@@ -1,10 +1,12 @@
 //
 //  NetBSD port:  
-//  Copyright (c) 1995, 1996, 1997 by Brian Grayson (bgrayson@ece.utexas.edu)
+//  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
 //  This file was written by Brian Grayson for the NetBSD and xosview
 //    projects.
-//  dummy device ignore code by : David Cuka (dcuka@intgp1.ih.att.com)
+//  This file contains code from the NetBSD project, which is covered
+//    by the standard BSD license.
+//  Dummy device ignore code by : David Cuka (dcuka@intgp1.ih.att.com)
 //  The OpenBSD interrupt meter code was written by Oleg Safiullin
 //    (form@vs.itam.nsc.ru).
 //  This file may be distributed under terms of the GPL or of the BSD
@@ -28,6 +30,12 @@
 
 #include <err.h>                /*  For err(), warn(), etc.  BCG  */
 #include <errno.h>
+#include <sys/dkstat.h>         /*  For CPUSTATES, which tells us how
+                                      many cpu states there are.  */
+#if defined(XOSVIEW_NETBSD) && !defined(CPUSTATES)
+#include <sys/sched.h>
+#endif
+
 #ifndef XOSVIEW_FREEBSD
 #include <sys/disk.h>		/*  For disk statistics.  */
 #endif
@@ -58,7 +66,9 @@ int DevStat_Get();
 #include <sys/malloc.h>
 #include <sys/sysctl.h>
 #include <sys/device.h>
-#if defined(XOSVIEW_NETBSD) && defined(__NetBSD_Version__) && (__NetBSD_Version__ <= 105010000)
+#if defined(__NetBSD_Version__) && __NetBSD_Version__ > 105010000 /* > 1.5A */
+#include <uvm/uvm_extern.h>
+#else
 #include <vm/vm.h>	/* This should only be needed for older versions
 			   of NetBSD, and even then I'm not sure it
 			   was truly necessary.  bgrayson */
@@ -76,7 +86,7 @@ int DevStat_Get();
 
 #ifdef HAVE_SWAPCTL
 #include <unistd.h>		/*  For swapctl proto.  */
-#if defined(XOSVIEW_NETBSD) && defined(__NetBSD_Version__) && __NetBSD_Version__ >= 104000000
+#if defined(XOSVIEW_OPENBSD) || (defined(XOSVIEW_NETBSD) && defined(__NetBSD_Version__) && __NetBSD_Version__ >= 104000000)
 #include <sys/swap.h>		/*  For swapent, SWAP_*.  */
 #else
 #include <vm/vm_swap.h>		/* swapent, SWAP_*. */
@@ -89,6 +99,7 @@ int DevStat_Get();
 #if _BSDI_VERSION >= 199802     /* BSD/OS 4.x */
 #include <i386/isa/icu.h>
 #endif
+
 // these two functions are declared in kvm_stat.h, unfortunately this file
 // has no c++ compatibility declerations
 __BEGIN_DECLS
@@ -99,6 +110,13 @@ __END_DECLS
 #include <sys/cpustats.h>
 #endif /* BSD/OS */
 
+// Utility/vanity define, for readability later on.
+// Note that this has to be after the above includes, which will pull
+// in __NetBSD_Version__ for us if needed.
+#if defined(XOSVIEW_NETBSD) && defined(__NetBSD_Version__) && (__NetBSD_Version__ >= 106010000)
+#define NETBSD_1_6A
+#endif
+
 #include "general.h"
 #include "kernel.h"		/*  To grab CVSID stuff.  */
 
@@ -113,41 +131,45 @@ kvm_t* kd = NULL;	//  This single kvm_t is shared by all
 //  This struct has the list of all the symbols we want from the kernel.
 static struct nlist nlst[] =
 {
+// We put a dummy symbol for a don't care, and ignore warnings about
+// this later on.  This keeps the indices within the nlist constant.
+#define DUMMY_SYM "dummy_sym"
+
 #if defined(XOSVIEW_BSDI) || (defined(XOSVIEW_NETBSD) && (__NetBSD_Version__ >= 104260000))
 // BSDI and __NetBSD_Version__ >= 104260000 reads cp_time through sysctl
-{ "_ifnet" },
+{ DUMMY_SYM },
 #define DUMMY_0
 #else
 { "_cp_time" },
-#define CP_TIME_SYM_INDEX 0
 #endif
+#define CP_TIME_SYM_INDEX 0
 { "_ifnet" },
 #define IFNET_SYM_INDEX 1
 #if defined(UVM)
-{ "_disklist" },	/*  Keep UVM happy...  */
+{ DUMMY_SYM },	/*  Keep UVM happy...  */
 #else
 { "_cnt" },
 #endif
 #define VMMETER_SYM_INDEX	2
 
 #ifdef XOSVIEW_BSDI /* bsdi get disk statistics through sysctl */
-{ "_cnt" },
+{ DUMMY_SYM },
 #define DUMMY_3                 3
-{ "_cnt" },
+{ DUMMY_SYM },
 #define DUMMY_4                 4
-{ "_cnt" },
+{ DUMMY_SYM },
 #define DUMMY_5                 5
-{ "_cnt" },
+{ DUMMY_SYM },
 #define DUMMY_6                 6
 #if _BSDI_VERSION >= 199802  /* BSD/OS 4.x */
 { "inin" },
 #define ININ_SYM_INDEX          7
-{ "inin" },
+{ DUMMY_SYM },
 #define DUMMY_8                 8
 #else /* BSD/OS 3.x */
 { "_isa_intr" },
 #define ISAINTR_SYM_INDEX       7
-{ "_isa_intr" },
+{ DUMMY_SYM },
 #define DUMMY_8                 8
 #endif /* _BSDI_VERSION */
 
@@ -155,20 +177,25 @@ static struct nlist nlst[] =
 #ifndef XOSVIEW_FREEBSD	/*  NetBSD has a disklist, which FreeBSD doesn't...  */
 { "_disklist" },
 #define DISKLIST_SYM_INDEX	3
-{ "_disklist" },
+{ DUMMY_SYM },
 #define DUMMY_4			4
-{ "_disklist" },
+{ DUMMY_SYM },
 #define DUMMY_5			5
-{ "_disklist" },
+{ DUMMY_SYM },
 #define DUMMY_6			6
 { "_intrcnt" },
 #define INTRCNT_SYM_INDEX 	7
 { "_eintrcnt" },
 #define EINTRCNT_SYM_INDEX 	8
 
-#if defined(XOSVIEW_OPENBSD) && (defined(pc532) || defined(i386))
+#if defined(NETBSD_1_6A)
+{"_allevents" },
+#define ALLEVENTS_SYM_INDEX	9
+#endif
 
-# ifdef i386
+#if defined(XOSVIEW_OPENBSD) && (defined(__pc532__) || defined(__i386__))
+
+# ifdef __i386__
 { "_intrhand" },
 #define INTRHAND_SYM_INDEX    9
 { "_intrstray" },
@@ -254,6 +281,11 @@ ValidSymbol (int index) {
 }
 
 
+int SymbolValue (int index) {
+  return (nlst[index].n_value);
+}
+
+
 void
 BSDInit() {
   kernelFileName[0] = '\0';
@@ -294,7 +326,7 @@ OpenKDIfNeeded() {
   //  Look at all of the returned symbols, and check for bad lookups.
   //  (This may be unnecessary, but better to check than not to...  )
   struct nlist * nlp = nlst;
-  while (nlp && nlp->n_name) {
+  while (nlp && nlp->n_name && strncmp(nlp->n_name, DUMMY_SYM, strlen(DUMMY_SYM))) {
     if ((nlp->n_type == 0) || (nlp->n_value == 0))
       /*errx (-1, "kvm_nlist() lookup failed for symbol '%s'.", nlp->n_name);*/
       warnx ("kvm_nlist() lookup failed for symbol '%s'.", nlp->n_name);
@@ -368,36 +400,44 @@ BSDGetCPUTimes (long* timeArray) {
   static int mib[] = { CTL_KERN, KERN_CPUSTATS };
 #endif
 #if defined(XOSVIEW_NETBSD) && (__NetBSD_Version__ >= 104260000)
-  u_int64_t cp_time[CPUSTATES];
-  size_t ssize = sizeof(cp_time);
   static int mib[] = { CTL_KERN, KERN_CP_TIME };
 #endif
 
   if (!timeArray) errx (-1, "BSDGetCPUTimes():  passed pointer was null!\n");
   if (CPUSTATES != 5)
     errx (-1, "Error:  xosview for *BSD expects 5 cpu states!\n");
+#if defined(__NetBSD_Version__) && __NetBSD_Version__ > 104260000 /* > 1.4Z */
+  struct schedstate_percpu ssp;
+  size_t size = sizeof(ssp.spc_cp_time);
+  if (sysctl(mib, 2, ssp.spc_cp_time, &size, NULL, 0) < 0) {
+    fprintf(stderr, "can't get schedstate_percpu: %s\n", strerror(errno));
+    memset(&ssp, 0, sizeof(ssp));
+  }
+  for (size = 0; size < CPUSTATES; size++)
+    timeArray[size] = (long) ssp.spc_cp_time[size];
+#else
 #ifdef XOSVIEW_BSDI
   if (sysctl(mib, 2, &cpu, &size, NULL, 0) < 0) {
     fprintf(stderr, "xosview: sysctl failed: %s\n", strerror(errno));
     bzero(&cpu, sizeof(cpu));
   }
   bcopy (cpu.cp_time,timeArray,sizeof (long) * CPUSTATES);
-#elif (defined(XOSVIEW_NETBSD) && (__NetBSD_Version__ >= 104260000))
-  if (sysctl(mib, 2, cp_time, &ssize, NULL, 0) < 0) {
-    fprintf(stderr, "xosview: sysctl failed: %s\n", strerror(errno));
-    bzero(cp_time, ssize);
-  }
-  bcopy (cp_time,timeArray,sizeof (u_int64_t) * CPUSTATES);
 #else
   safe_kvm_read_symbol (CP_TIME_SYM_INDEX, timeArray, sizeof (long) * CPUSTATES);
 #endif
+#endif
 }
 
 
 // ------------------------  NetMeter functions  ------------------
-void
+int
 BSDNetInit() {
   OpenKDIfNeeded();
+#ifdef XOSVIEW_NETBSD
+  return ValidSymbol(IFNET_SYM_INDEX);
+#else
+  return 1;
+#endif
 }
 
 void
@@ -493,8 +533,8 @@ BSDSwapInit() {
 //
 
 void
-BSDGetSwapCtlInfo(int *totalp, int *freep) {
-  int	totalinuse, totalsize;
+BSDGetSwapCtlInfo(unsigned long long *totalp, unsigned long long *freep) {
+  unsigned long long	totalinuse, totalsize;
   int rnswap, nswap = swapctl(SWAP_NSWAP, 0, 0);
   struct swapent *swapiter;
 
@@ -712,6 +752,8 @@ DevStat_Get(void) {
 }
 #endif /* HAVE_DEVSTAT */
 
+unsigned int NetBSD_N_Drives = 0;
+
 int
 BSDDiskInit() {
   OpenKDIfNeeded(); 
@@ -728,6 +770,18 @@ BSDDiskInit() {
   return ValidSymbol(DK_NDRIVE_SYM_INDEX);
 #endif
 #else
+#ifdef NETBSD_1_6A
+  // Do a sysctl with a NULL data pointer to get the size that would
+  // have been returned, and use that to figure out # drives.
+  int mib[3] = {CTL_HW, HW_DISKSTATS, sizeof(struct disk_sysctl)};
+  size_t size;
+  if (sysctl(mib, 3, NULL, &size, NULL, 0) < 0) {
+    warnx("!!! The DiskMeter sysctl failed.  Disabling DiskMeter.");
+    return 0;
+  }
+  NetBSD_N_Drives = size / sizeof(struct disk_sysctl);
+  return 1;
+#endif
   return ValidSymbol(DISKLIST_SYM_INDEX);
 #endif
 #endif /* BSDI */
@@ -759,6 +813,24 @@ BSDGetDiskXFerBytes (unsigned long long *bytesXferred) {
   *bytesXferred= 0;
   for (i=0;i<n;i++)
     *bytesXferred += bsdi_dkp[i].dk_sectors * bsdi_dkp[i].dk_secsize;
+#else
+#if defined(NETBSD_1_6A)
+  // Use the new sysctl to do this for us.
+  int mib[3] = {CTL_HW, HW_DISKSTATS, sizeof(struct disk_sysctl)};
+  size_t sysctl_size = NetBSD_N_Drives * sizeof(struct disk_sysctl);
+  struct disk_sysctl drive_stats[NetBSD_N_Drives];
+
+  // Do the sysctl.
+  if (sysctl(mib, 3, drive_stats, &sysctl_size, NULL, 0) < 0) {
+    err(1, "sysctl hw.diskstats failed");
+  }
+
+  // Now accumulate the total.
+  unsigned long long xferred = 0;
+  for (unsigned int i = 0; i < NetBSD_N_Drives; i++) {
+    xferred += drive_stats[i].dk_rbytes + drive_stats[i].dk_wbytes;
+  }
+  *bytesXferred = xferred;
 #else
   /*  This function is a little tricky -- we have to iterate over a
    *  list in kernel land.  To make things simpler, data structures
@@ -776,17 +848,23 @@ BSDGetDiskXFerBytes (unsigned long long *bytesXferred) {
   while (kvmdiskptr != NULL) {
     safe_kvm_read ((u_long)kvmdiskptr, &kvmcurrdisk, sizeof(kvmcurrdisk));
       /*  Add up the contribution from this disk.  */
+#if defined(__NetBSD_Version__) &&  __NetBSD_Version__ > 106070000 /* > 1.6G */
+    *bytesXferred += kvmcurrdisk.dk_rbytes + kvmcurrdisk.dk_wbytes;
+#else
     *bytesXferred += kvmcurrdisk.dk_bytes;
+#endif
 #ifdef DEBUG
     printf ("Got %#x (lower 32bits)\n", (int) (*bytesXferred & 0xffffffff));
 #endif
     kvmdiskptr = kvmcurrdisk.dk_link.tqe_next;
   }
 #endif
+#endif
 }
 
 /*  ---------------------- Interrupt Meter stuff  -----------------  */
-#if (!defined(XOSVIEW_OPENBSD) || !(defined(pc532) && defined(i386))) && !defined(XOSVIEW_BSDI)
+
+#if (!defined(XOSVIEW_OPENBSD) || !(defined(__pc532__) && defined(__i386__))) && !defined(XOSVIEW_BSDI) && !defined(NETBSD_1_6A)
 static unsigned long kvm_intrcnt[128];// guess at space needed
 #endif
 
@@ -806,9 +884,9 @@ int
 BSDIntrInit() {
     OpenKDIfNeeded();
 
-#if defined(XOSVIEW_OPENBSD) && defined(i386)
+#if defined(XOSVIEW_OPENBSD) && defined(__i386__)
     return ValidSymbol(INTRHAND_SYM_INDEX) && ValidSymbol(INTRSTRAY_SYM_INDEX);
-#elif defined (XOSVIEW_OPENBSD) && defined(pc532)
+#elif defined (XOSVIEW_OPENBSD) && defined(__pc532__)
     return ValidSymbol(IVP_SYM_INDEX);
 #elif defined (XOSVIEW_BSDI)
 #if _BSDI_VERSION >= 199802 /* BSD/OS 4.x */
@@ -817,11 +895,17 @@ BSDIntrInit() {
     return ValidSymbol(ISAINTR_SYM_INDEX);
 #endif /* _BSDI_VERSION */
 #else
-    return ValidSymbol(INTRCNT_SYM_INDEX) && ValidSymbol(EINTRCNT_SYM_INDEX);
+
+#if defined(NETBSD_1_6A)
+    return ValidSymbol(ALLEVENTS_SYM_INDEX);
+#else
+    // Make sure the intr counter array is nonzero in size.
+    return ValidSymbol(INTRCNT_SYM_INDEX) && ValidSymbol(EINTRCNT_SYM_INDEX) && ((SymbolValue(EINTRCNT_SYM_INDEX) - SymbolValue(INTRCNT_SYM_INDEX)) > 0);
+#endif
 #endif
 }
 
-#if (!defined(XOSVIEW_OPENBSD) || !(defined(pc532) || defined(i386))) && !defined (XOSVIEW_BSDI)
+#if (!defined(XOSVIEW_OPENBSD) || !(defined(__pc532__) || defined(__i386__))) && !defined (XOSVIEW_BSDI)
 int
 BSDNumInts() {
   int nintr;
@@ -882,8 +966,8 @@ BSDGetIntrStats (unsigned long intrCount[NUM_INTR]) {
   //  counts.  We'll just use the intrcnt array here.  If anyone
   //  has problems, please mail me.  bgrayson
   {
-#if defined(XOSVIEW_OPENBSD) && (defined(pc532) || defined(i386))
-# ifdef i386
+#if defined(XOSVIEW_OPENBSD) && (defined(__pc532__) || defined(__i386__))
+# ifdef __i386__
   struct intrhand *intrhand[16], *ihp, ih;
   int intrstray[16];
 
@@ -916,13 +1000,58 @@ BSDGetIntrStats (unsigned long intrCount[NUM_INTR]) {
       intrCount[i] = 0;
   }
 # endif /* pc532 */
-#else /* XOSVIEW_OPENBSD && (pc532 || i386) */
+#else /* XOSVIEW_OPENBSD && (__pc532__ || __i386__) */
+// Now let's do the modern NetBSD way...
+#if defined(NETBSD_1_6A)
+    // Shamelessly lifted from vmstat.c v1.119, with additional error
+    // checking and ignoring of soft interrupts, etc.
+
+    struct evcntlist allevents;
+    struct evcnt evcnt, *evptr;
+    char evname[EVCNT_STRING_MAX];
+
+    safe_kvm_read(nlst[ALLEVENTS_SYM_INDEX].n_value, &allevents, sizeof(allevents));
+    evptr = allevents.tqh_first;
+    int i = 0;
+
+    while (evptr && i < NUM_INTR) {
+
+      safe_kvm_read((unsigned int)evptr, &evcnt, sizeof(evcnt));
+
+      evptr = evcnt.ev_list.tqe_next;
+
+      // Skip non-interrupt event counts.
+      if (evcnt.ev_type != EVCNT_TYPE_INTR)
+	continue;
+
+      safe_kvm_read((unsigned int)evcnt.ev_name, evname, evcnt.ev_namelen);
+      // If it's a soft interrupt (has a name that starts with "soft"), skip it.
+      if (!strncmp(evname, "soft", 4))
+	continue;
+
+      // If we see counts that we can hold, record them...
+      if (i < NUM_INTR) {
+	intrCount[i] = evcnt.ev_count;
+      } else {
+	// ... otherwise accumulate them all into last bucket.
+	static bool firstTime = true;
+	intrCount[NUM_INTR-1] += evcnt.ev_count;
+	if (firstTime) {
+	  warnx("!!! Saw more than %d interrupts on event chain.", NUM_INTR);
+	  warnx("!!! Lumping remainder into last bucket.");
+	  firstTime = false;
+	}
+      }
+      i++;
+    }
+#else
     int nintr = BSDNumInts();
     safe_kvm_read(nlst[INTRCNT_SYM_INDEX].n_value, kvm_intrcnt,
       sizeof(long)*nintr);
     for (int i=0;i<nintr;i++) {
       intrCount[i] = kvm_intrcnt[i];
     }
+#endif
 #endif /* XOSVIEW_OPENBSD && (pc532 || i386) */
   }
   return;
