@@ -2,7 +2,7 @@
 //  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  NetBSD port:  
-//  Copyright (c) 1995, 1996, 1997 by Brian Grayson (bgrayson@ece.utexas.edu)
+//  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
 //  This file was written by Brian Grayson for the NetBSD and xosview
 //    projects.
@@ -34,7 +34,9 @@ SwapMeter::SwapMeter( XOSView *parent )
   useSwapCtl = 0;
 #endif
   BSDSwapInit();	//  In kernel.cc
+#if !(defined(XOSVIEW_OPENBSD) || defined(HAVE_SWAPCTL))
   if (!BSDInitSwapInfo())
+#endif
   {
 #ifdef HAVE_SWAPCTL
     //  Set up to use new swap code instead.
@@ -74,15 +76,22 @@ void SwapMeter::checkevent( void ){
 }
 
 void SwapMeter::getswapinfo( void ){
-  int total_int, free_int;
+  unsigned long long total_int, free_int;
 
   if (doSwap) {
 #ifdef HAVE_SWAPCTL
+    // Allow the option to use either swapctl() or other method.
     if (useSwapCtl)
       BSDGetSwapCtlInfo(&total_int, &free_int);
     else
 #endif
+#if defined(XOSVIEW_OPENBSD) || defined(HAVE_SWAPCTL)
+      // For OpenBSD or HAVE_SWAPCTL systems, _never_ use the older
+      // method if HAVE_SWAPCTL is set.
+      ;
+#else
       BSDGetSwapInfo (&total_int, &free_int);
+#endif
   }
   else {
     total_int = 1;	/*  So the meter looks blank.  */
