@@ -21,6 +21,7 @@
 #include "diskmeter.h"
 #include "raidmeter.h"
 #include "lmstemp.h"
+#include "nfsmeter.h"
 
 #include <stdlib.h>
 
@@ -57,7 +58,9 @@ void MeterMaker::makeMeters(void){
       push(new DiskMeter(_xos, atof(_xos->getResource("diskBandwidth"))));
 
   // check for the serial meters.
-#ifndef __mc68000__
+#if defined (__arm__) || defined(__mc68000__) || defined(__powerpc__) || defined(__sparc__) || defined(__s390__) || defined(__s390x__)
+  /* these architectures have no ioperm() */
+#else
   for (int i = 0 ; i < SerialMeter::numDevices() ; i++)
     if (_xos->isResourceTrue(SerialMeter::getResourceName(
       (SerialMeter::Device)i)))
@@ -99,4 +102,11 @@ void MeterMaker::makeMeters(void){
       push(new LmsTemp(_xos, res, lab, caption));
     }
   }
+  // check for the NFS mesters
+  if (_xos->isResourceTrue("NFSDStats")){
+      push(new NFSDStats(_xos));
+  }
+  if (_xos->isResourceTrue("NFSStats")){
+      push(new NFSStats(_xos));
+  }
 }
