@@ -1,4 +1,4 @@
-//  
+//
 //  Copyright (c) 1999 by Mike Romberg (romberg@fsl.noaa.gov)
 //
 //  This file may be distributed under terms of the GPL
@@ -9,7 +9,7 @@
 
 #include "fieldmetergraph.h"
 
-class DiskMeter : public FieldMeterGraph 
+class DiskMeter : public FieldMeterGraph
     {
     public:
         DiskMeter( XOSView *parent, float max );
@@ -17,15 +17,20 @@ class DiskMeter : public FieldMeterGraph
 
         const char *name( void ) const { return "DiskMeter"; }
         void checkevent( void );
-        
+
         void checkResources( void );
     protected:
 
         void getdiskinfo( void );
+        void getvmdiskinfo( void );
+        void updateinfo(unsigned long one, unsigned long two,
+          int fudgeFactor);
     private:
         unsigned long int read_prev_;
         unsigned long int write_prev_;
         float maxspeed_;
+        bool _vmstat;
+        char *_statFileName;
     };
 
 #endif
