@@ -1,4 +1,4 @@
-//  
+//
 //  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
@@ -7,8 +7,8 @@
 //
 #include "memmeter.h"
 #include "xosview.h"
-#include <fstream.h>
-#include <strstream.h>
+#include <fstream>
+#include <sstream>
 #include <stdlib.h>
 
 static const char MEMFILENAME[] = "/proc/meminfo";
@@ -19,7 +19,7 @@ MemMeter::MemMeter( XOSView *parent )
   _shAdj = -1;
 
   // Check and see if the memstat module has been loaded
-  ifstream test(MEMSTATFNAME);
+  std::ifstream test(MEMSTATFNAME);
   if (test){
     setNumFields(5);
     legend("USED/SHAR/BUFF/CACHE/FREE");
@@ -53,7 +53,7 @@ void MemMeter::checkResources( void ){
 
 void MemMeter::checkevent( void ){
   getmeminfo();
-  /* for debugging (see below) 
+  /* for debugging (see below)
   printf("t %4.1f used %4.1f share %4.1f buffer %4.1f cache %4.1f free %4.1f\n",
          total_/1024.0/1024.0,
          fields_[0]/1024.0/1024.0, fields_[1]/1024.0/1024.0,
@@ -83,25 +83,23 @@ void MemMeter::getmeminfo( void ){
     FieldMeterDecay::setUsed (total_ - fields_[4 + _shAdj], total_);
 }
 
-MemMeter::LineInfo *MemMeter::findLines(LineInfo *tmplate, int len, 
+MemMeter::LineInfo *MemMeter::findLines(LineInfo *tmplate, int len,
                                              const char *fname){
-  ifstream meminfo(fname);
+  std::ifstream meminfo(fname);
   if (!meminfo){
-    cerr << "Can not open file : " << fname << endl;
+    std::cerr << "Can not open file : " << fname << std::endl;
     exit(1);
   }
 
   LineInfo *rval = new LineInfo[len];
 
   char buf[256];
-  istrstream line(buf, 256);
 
   // Get the info from the "standard" meminfo file.
   int lineNum = 0;
   int inum = 0;  // which info are we going to insert
   while (!meminfo.eof()){
     meminfo.getline(buf, 256);
-    line.seekg(0, ios::beg);
     lineNum++;
 
     for (int i = 0 ; i < len ; i++)
@@ -116,8 +114,8 @@ MemMeter::LineInfo *MemMeter::findLines(LineInfo *tmplate, int len,
 }
 
 void MemMeter::initLineInfo(void){
-  static LineInfo infos[] = { 
-    LineInfo("MemTotal", &total_), 
+  static LineInfo infos[] = {
+    LineInfo("MemTotal", &total_),
     LineInfo("MemFree", &fields_[4 + _shAdj]),
     LineInfo("Buffers", &fields_[2 + _shAdj]),
     LineInfo("Cached", &fields_[3 + _shAdj])
@@ -136,16 +134,13 @@ void MemMeter::initLineInfo(void){
 }
 
 void MemMeter::getmemstat(const char *fname, LineInfo *infos, int ninfos){
-  ifstream meminfo(fname);
+  std::ifstream meminfo(fname);
   if (!meminfo){
-    cerr << "Can not open file : " << fname << endl;
+    std::cerr << "Can not open file : " << fname << std::endl;
     exit(1);
   }
 
   char buf[256];
-  istrstream line(buf, 256);
-
-  char ignore[256];
 
   // Get the info from the "standard" meminfo file.
   int lineNum = 0;
@@ -153,16 +148,16 @@ void MemMeter::getmemstat(const char *fname, LineInfo *infos, int ninfos){
   while (!meminfo.eof()){
     meminfo.getline(buf, 256);
     lineNum++;
-
     if (lineNum != infos[inum].line())
       continue;
 
-    line.seekg(0, ios::beg);
-
+    std::string sline(buf, 256);
+    std::istringstream line(sline);
     unsigned long val;
+    std::string ignore;
     line >> ignore >> val;
     /*  All stats are in KB.  */
-    infos[inum].setVal(val*1024);	/*  Multiply by 1024 bytes per K  */
+    infos[inum].setVal(val*1024.0);	/*  Multiply by 1024 bytes per K  */
 
     inum++;
     if (inum >= ninfos)
