@@ -1,4 +1,4 @@
-//  
+//
 //  Copyright (c) 1996 by Massimiliano Ghilardi ( ghilardi@cibs.sns.it )
 //
 //  This file may be distributed under terms of the GPL
@@ -24,8 +24,12 @@ protected:
   float pageinfo_[2][2];
   int pageindex_;
   float maxspeed_;
+  bool _vmstat;
+  char *_statFileName;
 
   void getpageinfo( void );
+  void getvmpageinfo( void );
+  void updateinfo(void);
 private:
 };
 
