@@ -16,8 +16,8 @@
 #include <sys/ioctl.h>
 #include <errno.h>
 #include <stdlib.h>
-#include <strstream.h>
-#include <iomanip.h>
+#include <sstream>
+#include <iomanip>
 
 // This should go away after types.h gets fixed in the kernel.
 #ifdef __alpha__
@@ -32,12 +32,15 @@ typedef unsigned long long u64;
 
 #include <unistd.h>
 #if defined(GNULIBC) || defined(__GLIBC__)
+#if !defined(__hppa__) && !defined(__mips__)
 #include <sys/io.h>
-#ifndef __alpha__
+#endif
+#if !defined(__alpha__) && !defined(__sparc__) && !defined(__powerpc__) && !defined(__ia64__) && !defined(__hppa__) && !defined(__arm__) && !defined(__mips__)
 #include <sys/perm.h>
+#define HAVE_IOPERM
 #endif
 #else
-#ifndef __alpha__
+#if !defined(__alpha__) && !defined(__sparc__) && !defined(__powerpc__) && !defined(__ia64__)
 #include <asm/io.h>
 #endif
 #endif
@@ -66,23 +69,29 @@ void SerialMeter::checkResources( void ){
 
   _port = getPortBase(_device);
   if (!getport(_port + UART_LSR) || !getport(_port + UART_MSR)){
-    cerr << "SerialMeter::SerialMeter() : "
-         << "xosview must be suid root to use the serial meter." <<endl;
+    std::cerr << "SerialMeter::SerialMeter() : "
+         << "xosview must be suid root to use the serial meter." << std::endl;
     parent_->done(1);
   }
 }
 
 bool SerialMeter::getport(unsigned short int port){
+#ifdef HAVE_IOPERM
   return ioperm(port, 1, 1) != -1;
+#else
+  return -1 != -1;
+#endif
 }
 
 void SerialMeter::getserial( void ){
+#ifdef HAVE_IOPERM
   // get the LSR and MSR
   unsigned char lsr = inb(_port + UART_LSR);
   unsigned char msr = inb(_port + UART_MSR);
 
   setBits(0, lsr);
   setBits(8, msr);
+#endif
 }
 
 const char *SerialMeter::getTitle(Device dev) const {
@@ -122,12 +131,13 @@ unsigned short int SerialMeter::getPortBase(Device dev) const {
 
     // get the real serial port (code stolen from setserial 2.11)
     if ((fd = open(deviceFile[dev], O_RDONLY|O_NONBLOCK)) < 0) {
-      cerr << "SerialMeter::SerialMeter() : "
-           << "failed to open " << deviceFile[dev] <<"." <<endl;
+      std::cerr << "SerialMeter::SerialMeter() : "
+           << "failed to open " << deviceFile[dev] <<"." <<std::endl;
       exit(1);
     }
     if (ioctl(fd, TIOCGSERIAL, &serinfo) < 0) {
-      cerr << "Failed to detect port base for " << deviceFile[dev] << endl;
+      std::cerr << "Failed to detect port base for " << deviceFile[dev]
+        << std::endl;
       close(fd);
       exit(1);
     }
@@ -136,9 +146,10 @@ unsigned short int SerialMeter::getPortBase(Device dev) const {
     return serinfo.port;
   }
   else { // Use user specified port base.
-    istrstream istrm(res);
+    std::string s(res);
+    std::istringstream istrm(s);
     unsigned short int tmp = 0;
-    istrm >> hex >> tmp;
+    istrm >> std::hex >> tmp;
     return tmp;
   }
 
