@@ -1,4 +1,4 @@
-//  
+//
 //  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
@@ -9,8 +9,8 @@
 
 #include "swapmeter.h"
 #include "xosview.h"
-#include <fstream.h>
-#include <strstream.h>
+#include <fstream>
+#include <sstream>
 #include <stdlib.h>
 
 #ifdef USESYSCALLS
@@ -28,7 +28,7 @@ static const char MEMFILENAME[] = "/proc/meminfo";
 
 SwapMeter::SwapMeter( XOSView *parent )
 : FieldMeterGraph( parent, 2, "SWAP", "USED/FREE" ){
-  
+
 }
 
 SwapMeter::~SwapMeter( void ){
@@ -54,6 +54,7 @@ void SwapMeter::checkevent( void ){
 #ifdef USESYSCALLS
 void SwapMeter::getswapinfo( void ){
   struct sysinfo sinfo;
+  int unit;
 
 #if defined(GNULIBC) || defined(__GLIBC__)
   sysinfo(&sinfo);
@@ -61,24 +62,26 @@ void SwapMeter::getswapinfo( void ){
   syscall( SYS_sysinfo, &sinfo );
 #endif
 
-  total_ = sinfo.totalswap;
-  fields_[0] = total_ - sinfo.freeswap;
-  fields_[1] = sinfo.freeswap;
+  unit = (sinfo.mem_unit ? sinfo.mem_unit : 1); 
+
+  total_ = sinfo.totalswap * unit;
+  fields_[0] = (sinfo.totalswap - sinfo.freeswap) * unit;
+  fields_[1] = sinfo.freeswap * unit;
 
   if ( total_ == 0 ){
     total_ = 1;
     fields_[0] = 0;
     fields_[1] = 1;
   }
-  
+
   if (total_)
     setUsed (fields_[0], total_);
 }
 #else
 void SwapMeter::getswapinfo( void ){
-  ifstream meminfo( MEMFILENAME );
+  std::ifstream meminfo( MEMFILENAME );
   if ( !meminfo ){
-    cerr <<"Con not open file : " <<MEMFILENAME <<endl;
+    std::cerr <<"Con not open file : " <<MEMFILENAME << std::endl;
     exit( 1 );
   }
 
@@ -98,7 +101,7 @@ void SwapMeter::getswapinfo( void ){
     if(!strncmp("SwapFree", buf, strlen("SwapFree")))
         line >> ignore >> fields_[1];
   }
-  
+
   fields_[0] = total_ - fields_[1];
 
   if ( total_ == 0 ){
@@ -111,4 +114,3 @@ void SwapMeter::getswapinfo( void ){
     setUsed (fields_[0], total_);
 }
 #endif
-
