@@ -22,8 +22,8 @@ XWin::XWin(){
 //-----------------------------------------------------------------------------
 
 XWin::XWin( int argc, char *argv[], int x, int y, int width, int height ){
-  cerr << "This constructor call is not supported! (" << __FILE__
-       << ":" << __LINE__ << ")" << endl;
+  std::cerr << "This constructor call is not supported! (" << __FILE__
+       << ":" << __LINE__ << ")" << std::endl;
   exit (-1);
   //  FIXME BCG  This constructor needs to do much of the work of the above
   //  one.  Or, we need to drop this as a constructor.  As it is, it is
@@ -102,6 +102,7 @@ void XWin::init( int argc, char **argv ){
 				1,
 				fgcolor_, bgcolor_);
 
+
   setHints( argc, argv );
 
   // Finally, create a graphics context for the main window
@@ -123,6 +124,12 @@ void XWin::init( int argc, char **argv ){
 	XSetWindowBackgroundPixmap(display_,window_,background_pixmap);
   }
 
+  // Do transparency if requested
+  if(isResourceTrue("transparent"))
+  {
+        XSetWindowBackgroundPixmap(display_,window_,ParentRelative);
+  }         
+  
   // add the events
   Event *tmp = events_;
   while ( tmp != NULL ){
@@ -134,7 +141,7 @@ void XWin::init( int argc, char **argv ){
   map();
   flush();
   if(XGetWindowAttributes(display_, window_, &attr_) == 0){
-    cerr <<"Error getting attributes of Main." <<endl;
+    std::cerr <<"Error getting attributes of Main." <<std::endl;
     exit(2);
   }
 
@@ -154,8 +161,8 @@ void XWin::setFont( void ){
   const char* fontName = getResource("font");
 
   if ((font_ = XLoadQueryFont(display_, fontName)) == NULL){
-    cerr <<name_ <<": display " <<DisplayString(display_)
-      <<" cannot load font " << fontName << endl;
+    std::cerr <<name_ <<": display " <<DisplayString(display_)
+      <<" cannot load font " << fontName << std::endl;
     exit(1);
   }
 }
@@ -164,7 +171,7 @@ void XWin::setFont( void ){
 void XWin::setHints( int argc, char *argv[] ){
   // Set up class hint
   if((classhints_ = XAllocClassHint()) == NULL){
-    cerr <<"Error allocating class hint!" <<endl;
+    std::cerr <<"Error allocating class hint!" <<std::endl;
     exit(1);
   }
   //  We have to cast away the const's.
@@ -173,7 +180,7 @@ void XWin::setHints( int argc, char *argv[] ){
 
   // Set up the window manager hints
   if((wmhints_ = XAllocWMHints()) == NULL){
-    cerr <<"Error allocating Window Manager hints!" <<endl;
+    std::cerr <<"Error allocating Window Manager hints!" <<std::endl;
     exit(1);
   }
   wmhints_->flags = (InputHint|StateHint);
@@ -182,11 +189,11 @@ void XWin::setHints( int argc, char *argv[] ){
 
   // Set up XTextProperty for window name and icon name
   if(XStringListToTextProperty(&name_, 1, &title_) == 0){
-    cerr <<"Error creating XTextProperty!" <<endl;
+    std::cerr <<"Error creating XTextProperty!" <<std::endl;
     exit(1);
   }
   if(XStringListToTextProperty(&name_, 1, &iconname_) == 0){
-    cerr <<"Error creating XTextProperty!" <<endl;
+    std::cerr <<"Error creating XTextProperty!" <<std::endl;
     exit(1);
   }
 
@@ -204,7 +211,7 @@ void XWin::setHints( int argc, char *argv[] ){
 void XWin::openDisplay( void ){
   // Open connection to display selected by user
   if ((display_ = XOpenDisplay (display_name_)) == NULL) {
-    cerr <<"Can't open display named " << display_name_ <<endl;
+    std::cerr <<"Can't open display named " << display_name_ <<std::endl;
     exit(1);
   }
 
@@ -240,10 +247,32 @@ int XWin::getPixmap(Pixmap *pixmap)
 	XWindowAttributes    root_att;
 	XpmAttributes        pixmap_att;
 
+//	if (isResourceTrue("transparent"))
+//	{
+//		Atom act_type;
+//		int act_format;
+//		unsigned long nitems, bytes_after;
+//		unsigned char *prop = NULL;
+//
+//		if (XGetWindowProperty(display_, window_,
+//		                       XInternAtom (display_, "_XROOTPMAP_ID", True),
+//		                       0, 1, False, XA_PIXMAP, &act_type, &act_format,
+//		                       &nitems, &bytes_after, &prop) != Success)
+//		{
+//			cerr << "Unable to get root window pixmap" << endl;
+//			cerr << "Defaulting to blank" << endl;
+//			pixmap=NULL;
+//			return 0; // OOps
+//		}
+//
+//		pixmap = (Pixmap *) prop;
+//		XFree (prop);
+//		return 1;  // Good, got the pixmap of the root window
+//	}
 
 	pixmap_file = (char*) getResourceOrUseDefault("pixmapName",NULL);
 
-	if(pixmap_file)
+	if (pixmap_file)
 	{
 		XGetWindowAttributes(display_, DefaultRootWindow(display_),&root_att);
 		pixmap_att.closeness=30000;
@@ -251,8 +280,8 @@ int XWin::getPixmap(Pixmap *pixmap)
 		pixmap_att.valuemask=XpmSize|XpmReturnPixels|XpmColormap|XpmCloseness;
 		if(XpmReadFileToPixmap(display_,DefaultRootWindow(display_),pixmap_file, pixmap, NULL, &pixmap_att))
         	{
-                	cerr << "Pixmap " << pixmap_file  << " not found" << endl;
-                	cerr << "Defaulting to blank" << endl;
+                	std::cerr << "Pixmap " << pixmap_file  << " not found" << std::endl;
+                	std::cerr << "Defaulting to blank" << std::endl;
                 	pixmap=NULL;
 			return 0; // OOps
         	}
@@ -261,7 +290,7 @@ int XWin::getPixmap(Pixmap *pixmap)
 	return 0; // No file specified, none used
 #else
 	(void) pixmap;
-	cerr << "Error:  getPixmap called, when Xpm is not enabled!\n" ;
+	std::cerr << "Error:  getPixmap called, when Xpm is not enabled!\n" ;
 	return 0;
 #endif
 }
@@ -273,7 +302,7 @@ void XWin::getGeometry( void ){
   // Fill out a XsizeHints structure to inform the window manager
   // of desired size and location of main window.
   if((sizehints_ = XAllocSizeHints()) == NULL){
-    cerr <<"Error allocating size hints!" <<endl;
+    std::cerr <<"Error allocating size hints!" <<std::endl;
     exit(1);
   }
   sizehints_->flags = PSize;
@@ -350,7 +379,7 @@ void XWin::checkevent( void ){
 #if 0
 void XWin::usage( void ){
   //  FIXME  We need to update this.  BCG
-  cerr <<name_ <<" [-display name] [-geometry geom]" <<endl;
+  std::cerr <<name_ <<" [-display name] [-geometry geom]" <<std::endl;
 //    exit (1);
 }
 #endif
@@ -386,7 +415,7 @@ const char *XWin::getResource( const char *name ){
     return retval;
   else
   {
-    cerr << "Error:  Couldn't find '" << name << "' resource in the resource database!\n";
+    std::cerr << "Error:  Couldn't find '" << name << "' resource in the resource database!\n";
     exit (-1);
       /*  Some compilers aren't smart enough to know that exit() exits.  */
     return '\0';
@@ -395,8 +424,8 @@ const char *XWin::getResource( const char *name ){
 
 //-----------------------------------------------------------------------------
 
-void XWin::dumpResources( ostream &os ){
-cerr << "Function not implemented!\n";  //  BCG  FIXME  Need to make this.
+void XWin::dumpResources( std::ostream &os ){
+std::cerr << "Function not implemented!\n";  //  BCG  FIXME  Need to make this.
 (void) os;  //  Keep gcc happy.
 }
 //-----------------------------------------------------------------------------
@@ -405,7 +434,7 @@ unsigned long XWin::allocColor( const char *name ){
   XColor exact, closest;
   
   if ( XAllocNamedColor( display_, colormap(), name, &closest, &exact ) == 0 )
-    cerr <<"XWin::allocColor() : failed to alloc : " <<name <<endl;
+    std::cerr <<"XWin::allocColor() : failed to alloc : " <<name <<std::endl;
 
   return exact.pixel;
 }
@@ -504,7 +533,7 @@ XWin::Event::Event( XWin *parent, int event, EventCallBack callBack ){
     mask_ = ResizeRedirectMask;
     break;
   default:
-    cerr <<"XWin::Event::Event() : unknown event type : " <<event_ <<endl;
+    std::cerr <<"XWin::Event::Event() : unknown event type : " <<event_ <<std::endl;
     mask_ = NoEventMask;
     break;
   }
